Atomic

Struct Atomic 

pub struct Atomic<W: Well>(/* private fields */);
Atomic potential well.

Internally, this just wraps a pointer to Bucket<T> and uses atomic pointer operations to access it. However, the number of operations on the pointer is limited to ensure correctness in safe code.

Implementations

Source

impl<W: Well> Atomic<W>

pub fn new(well: W) -> Atomic<W>

Creates atomic with a value.

pub unsafe fn as_raw_unchecked(&self) -> &AtomicPtr<Target<W>>

Gives access to the underlying AtomicPtr.

Safety

The pointer inside the atomic must always a valid pointer from Well::remove and therefore must not be null. Additionally, keep in mind that this atomic owns the pointer, and if you want to move it out, you must put a different pointer in its place first.

pub fn swap(&self, well: W, ordering: Ordering) -> W

Atomically swaps the data inside the well.

This is equivalent to an atomic swap.

Source

impl<W: WeakWell> Atomic<W>

pub fn try_load(&self, ordering: Ordering) -> Option<<W as WeakWell>::Strong>

Tries to load the inner data.

This is equivalent to an atomic load, but it may fail due to the weak reference.

Source

impl<W: StrongWell + Deref<Target: Sized>> Atomic<W>

pub fn load(&self, ordering: Ordering) -> &Target<W>

Loads the inner data as an immutable reference.

This is equivalent to an atomic load.

pub fn swap_get(&self, well: W, ordering: Ordering) -> (W, &Target<W>)

Atomically swaps the data inside the well and returns a reference to the new data.

This is swap, but with the unsafe deref hidden behind a safe API.

Source

impl<W: StrongWellMut + DerefMut<Target: Unpin>> Atomic<W>

pub fn load_mut(&mut self) -> &mut Target<W>

Loads the inner data as a mutable reference.

This performs a non-atomic access since the atomic is mutably borrowed.

Source

impl<W: StrongWellMut> Atomic<Pin<W>>

pub fn load_mut_pinned(&mut self) -> Pin<&mut <Pin<W> as Well>::Target>

Loads the inner data as a mutable reference.

This is a version of load_mut that works with pinned values.

Source

impl<W: Well + Clone> Atomic<W>

pub fn load_clone(&self, ordering: Ordering) -> W

Loads a clone of the inner data.

This still performs an atomic load, but instead of offering a reference, the smart pointer is cloned instead.