Atomic boxes.
You can use Atomic and AtomicOption to access owned pointers to values atomically,
and determine whether smart pointers have to be stored in the atomic.
You can also implement your own smart pointer types using the Well trait.
Structs
- Atomic
- Atomic potential well.
- Atomic
Option - Potentially empty atomic potential well.
Traits
- Well
- Place that can store a smart pointer.