pub type KineticWell<T, W> = <W as PotentialWell>::Well<T>;Expand description
Gets a well from a PotentialWell.
In case you haven’t gotten the joke by now, an “atom in a box” is called a potential well in physics, and well, kinetic energy is the opposite of potential energy.
It’s a bad joke. But this type shouldn’t be necessary unless you’re writing really generic
code, since most of the time, you’ll be using one of the many aliases for PotentialAtomic
and PotentialAtomicOption, which will just turn something like
KineticWell<T, W<()>> into W<T>.